==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/antistring/translations/antistring_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Block message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Admonition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Write log to file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conditions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Factor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/antistring/translations/antistring_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversa</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Block message</source>
        <translation>Bloquear mensagem</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Condições</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condição</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Não use</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Fator</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Mudar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
